==> clickhouse-s3-etl-tools-0.0.9.tar.gz: clickhouse-s3-etl-tools-0.0.9/clickhouse_s3_etl_tools/s3_to_clickhouse_transfer/config_module.py <==
import argparse
import os

from clickhouse_s3_etl_tools.configs import (
    DEFAULT_VALUE_BATCH_SIZE,
    DEFAULT_VALUE_LOG_LEVEL,
)
from clickhouse_s3_etl_tools.schema.schema_configs import Configuration


def get_configuration() -> Configuration:
    parser = argparse.ArgumentParser(
        description="Script processes data from S3 and transfers it to ClickHouse instance. "
        "Specify S3 and ClickHouse connection details, table configuration, and other options."
    )

    # Define command-line arguments

    parser.add_argument(
        "--ch-url-destination", type=str, help="ClickHouse Destination URL"
    )

    parser.add_argument("--s3-access-key", type=str, help="S3 Access Key")
    parser.add_argument("--s3-secret-key", type=str, help="S3 Secret Key")
    parser.add_argument("--s3-path", type=str, help="S3 Path")

    parser.add_argument("--table-name", type=str, help="Table Name")
    parser.add_argument("--database", type=str, help="Database")
    parser.add_argument("--database-destination", type=str, help="Destination Database")

    parser.add_argument(
        "--batch-size", type=int, default=DEFAULT_VALUE_BATCH_SIZE, help="Batch Size"
    )
    parser.add_argument(
        "--log-level", type=str, default=DEFAULT_VALUE_LOG_LEVEL, help="Log Level"
    )

    parser.add_argument(
        "--drop-destination-table-if-exists",
        action="store_true",
        help="Drop destination table if exists",
    )

    parser.add_argument(
        "--use-s3-cluster",
        action="store_true",
        help="Use S3cluster",
    )

    parser.add_argument(
        "--on-cluster-directive",
        type=str,
        help="Directive for cluster configuration (default: " ")",
    )

    # Parse command-line arguments
    args = parser.parse_args()

    # Construct raw config dictionary
    raw_config = {
        "s3": {
            "S3_ACCESS_KEY": args.s3_access_key or os.getenv("S3_ACCESS_KEY"),
            "S3_SECRET_KEY": args.s3_secret_key or os.getenv("S3_ACCESS_SECRET"),
            "PATH_S3": args.s3_path or os.getenv("PATH_S3"),
        },
        "clickhouse": {
            "CH_URL_SOURCE": "not_available",
            "CH_URL_DESTINATION": args.ch_url_destination
            or os.getenv("CH_URL_DESTINATION"),
        },
        "table": {
            "TABLE_NAME": args.table_name or os.getenv("TABLE_NAME"),
            "DATABASE": args.database or os.getenv("DATABASE"),
            "DATABASE_DESTINATION": args.database_destination
            or os.getenv("DATABASE_DESTINATION"),
        },
        "BATCH_SIZE": args.batch_size or os.getenv("BATCH_SIZE"),
        "LOG_LEVEL": args.log_level,
        "DROP_DESTINATION_TABLE_IF_EXISTS": args.drop_destination_table_if_exists,
        "ON_CLUSTER_DIRECTIVE": args.on_cluster_directive
        or os.getenv("ON_CLUSTER_DIRECTIVE"),
        "USE_S3_CLUSTER": args.use_s3_cluster or os.getenv("USE_S3_CLUSTER"),
    }

    # Create Configuration instance
    return Configuration(**raw_config)

==> clickhouse-s3-etl-tools-0.1.8.tar.gz: clickhouse-s3-etl-tools-0.1.8/clickhouse_s3_etl_tools/s3_to_clickhouse_transfer/config_module.py <==
import argparse
import os

from clickhouse_s3_etl_tools.configs import (
    DEFAULT_VALUE_BATCH_SIZE,
    DEFAULT_VALUE_LOG_LEVEL,
)
from clickhouse_s3_etl_tools.schema.schema_configs import Configuration


def get_configuration() -> Configuration:
    parser = argparse.ArgumentParser(
        description="Script processes data from S3 and transfers it to ClickHouse instance. "
        "Specify S3 and ClickHouse connection details, table configuration, and other options."
    )

    # Define command-line arguments

    parser.add_argument(
        "--ch-url-destination", type=str, help="ClickHouse Destination URL"
    )

    parser.add_argument("--s3-access-key", type=str, help="S3 Access Key")
    parser.add_argument("--s3-secret-key", type=str, help="S3 Secret Key")
    parser.add_argument("--s3-path", type=str, help="S3 Path")

    parser.add_argument("--table-name", type=str, help="Table Name")
    parser.add_argument("--database", type=str, help="Database")
    parser.add_argument("--database-destination", type=str, help="Destination Database")

    parser.add_argument(
        "--batch-size", type=int, default=DEFAULT_VALUE_BATCH_SIZE, help="Batch Size"
    )
    parser.add_argument(
        "--log-level", type=str, default=DEFAULT_VALUE_LOG_LEVEL, help="Log Level"
    )

    parser.add_argument(
        "--drop-destination-table-if-exists",
        action="store_true",
        help="Drop destination table if exists",
    )

    parser.add_argument(
        "--use-s3-cluster",
        action="store_true",
        help="Use S3cluster",
    )

    parser.add_argument(
        "--cluster_name",
        type=str,
        help="Directive for cluster configuration (default: " ")",
    )

    # Parse command-line arguments
    args = parser.parse_args()

    # Construct raw config dictionary
    raw_config = {
        "s3": {
            "S3_ACCESS_KEY": args.s3_access_key or os.getenv("S3_ACCESS_KEY"),
            "S3_SECRET_KEY": args.s3_secret_key or os.getenv("S3_SECRET_KEY"),
            "PATH_S3": args.s3_path or os.getenv("PATH_S3"),
        },
        "clickhouse": {
            "CH_URL_SOURCE": "not_available",
            "CH_URL_DESTINATION": args.ch_url_destination
            or os.getenv("CH_URL_DESTINATION"),
        },
        "table": {
            "TABLE_NAME": args.table_name or os.getenv("TABLE_NAME"),
            "DATABASE": args.database or os.getenv("DATABASE"),
            "DATABASE_DESTINATION": args.database_destination
            or os.getenv("DATABASE_DESTINATION"),
        },
        "BATCH_SIZE": args.batch_size,
        "LOG_LEVEL": args.log_level,
        "DROP_DESTINATION_TABLE_IF_EXISTS": args.drop_destination_table_if_exists,
        "CLUSTER_NAME": args.cluster_name or os.getenv("CLUSTER_NAME"),
        "USE_S3_CLUSTER": args.use_s3_cluster or os.getenv("USE_S3_CLUSTER"),
    }

    # Create Configuration instance
    return Configuration(**raw_config)
